bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution.compute_mask_to_parent
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletDistribution.compute_mask_to_parent